function finish(arg)
% finish  Function to save names of files being edited and search path
%  2012-12-02  Matlab8  Copyright (c) 2012, W J Whiten  BSD License
% 
% finish
%  Is run automatically when Matlab exits, or from startup.m
%  Records names of files open in editor into file savededit.mat
%  Records user search path files into file savedpath.mat
%
% In startup.m if above files exist in selected directory 
%  startup will restore editor files and search path.
%
% Called with argument by startup.m to save name of selected folder
% May fail to save editor files in earlier versions of Matlab
%
% Does not save files if current directory changed from when startup run

persistent workdir

% save working directory if given
if(nargin>0)
    workdir=arg;
    return
end

% skip if no workdir
if(isempty(workdir))
    return
end

% save if current directory and gbl_adddir agree
if(strcmp(cd(),workdir))
    % save the names of files open in the editor and close the files
    try
        v1=version;
        if(str2double(v1(1:3))>=8.0 || str2double(v1(1:4))>=7.12)
            allDocs=matlab.desktop.editor.getAll; 
            % help matlab.desktop.editor
        else
            allDocs=editorservices.getAll;  % doc editorservices
        end
        savededit={allDocs.Filename};
        allDocs.close;
        save savededit.mat savededit;

    catch %#ok<CTCH>
        commandwindow
        beep
        disp('\b****')
        disp('Failed to save names of open files')
        disp('\b****')
        beep
        pause(5);
        %input('Return to continue')
    end

    % save the search path
    try
        t=path();
        i=strfind(t,matlabroot());
        savedpath=t(1:i(1)-2);
        save savedpath.mat savedpath;
    catch %#ok<CTCH>
        commandwindow
        beep
        disp('\b****')
        disp('Failed to save search path')
        disp('\b****')
        beep
        pause(5);
        %input('Return to continue')
    end

else
    commandwindow
    beep
    disp('\b***')
    disp(['Current directory changed: '  ...
        'savedpath and savededit files not updated'])
    disp('\b***')
    beep
    pause(5);
    %input('Return to continue')
end

return
end
