function startup
% startup File to set current directory, restores path & editor
%  2012-12-02  Matlab8  Copyright (c) 2012, W J Whiten  BSD License
%
% startup
% Runs during startup if found on the directory path;
% Requests selection of working folder and
%  if path information has been saved resets path,
%  if editor information saved reopens files.
% finish.m saves path information and editor information 
%  when Matlab closes or startup is run again.
%
% Also can be run from command line to move to a new working folder.
%
% Put startup.m and finish.m in a folder and set that folder on 
%  default path, when startup runs, select folder to work in.

persistent workdir savedir

% clean up if not first call
if(~isempty(workdir))
    if(~isempty(which('finish')))
        finish
    end
    
    % remove user directories
    userdir=path();
    i=strfind(userdir,matlabroot());
    userdir=userdir(1:i(1)-2);
    rmpath(userdir);
    
    % add path originally saved during start up
    addpath(savedir);
    
else
    
    % save initialpath
    t=path();
    i=strfind(t,matlabroot());
    savedir=t(1:i(1)-2);
    
end

% select folder and save
cdfile=fileparts(mfilename('fullpath'));
workdir1=uigetdir(cdfile,'Select your working folder');

if(all(workdir1==0) || ~ischar(workdir1) || isempty(workdir1))
    if(isempty(workdir))
        cd(cdfile);
        return
    end
    workdir1=workdir;
end

% save workdir and make current directory
workdir=workdir1;
cd(workdir);

% send workdir to finish
if(~isempty(which('finish')))
    finish(workdir)
end

% look for savedpath file in current directory only
disp('Path:')
if(strcmp(workdir,fileparts(which('savedpath.mat'))))

    % restore path and list directories used
    spath=load('savedpath.mat');
    if(isempty(spath.savedpath))
        spath.savedpath=workdir;
    end
    addpath(spath.savedpath);
    indx=[0,strfind(spath.savedpath,pathsep),length(spath.savedpath)+1];
    for i=2:length(indx)
        disp(['dir= ',spath.savedpath(indx(i-1)+1:indx(i)-1)])
    end
else
    
    % list directories used
    indx=[0,strfind(savedir,pathsep),length(savedir)+1];
    for i=2:length(indx)
        disp(['dir= ',savedir(indx(i-1)+1:indx(i)-1)])
    end
    disp(['dir= ',workdir])
end

% set new current directory and ensure it is at top of path
addpath(workdir);
cd(workdir);
disp(' ')
disp(['cd=  ',workdir])

% reload editor files if saved
if(strcmp(workdir,fileparts(which('savededit.mat'))))
    sedit=load('savededit.mat');
    for i=1:length(sedit.savededit) 
        if(~strcmp(sedit.savededit{i},'untitled'))
            edit(sedit.savededit{i});
        end
    end
end

% return to command window
commandwindow

% output any messages
disp(' ')
disp('Wishing you a productive and enjoyable Matlab session')
disp('doc (or helpwin) for file help')

return
end
